AlertHelper class

Constructors

AlertHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showCustomAlert({required BuildContext context, required bool? status, required String title, required String desc, required String buttonText, required String? buttonTextSecondary, VoidCallback? action, VoidCallback? actionSecondary}) → void